@@ -262,7 +262,7 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 			return utils.NewDataVolumeForUpload(dataVolumeName, size)
 		}
 
-		table.DescribeTable("should", func(args dataVolumeTestArguments) {
+		testDataVolume := func(args dataVolumeTestArguments) {
 			// Have to call the function in here, to make sure the BeforeEach in the Framework has run.
 			dataVolume := args.dvFunc(args.name, args.size, args.url())
 			startTime := time.Now()
@@ -335,7 +335,9 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 					return false
 				}, timeout, pollingInterval).Should(BeTrue())
 			}
-		},
+		}
+
+		table.DescribeTable("should", testDataVolume,
 			table.Entry("[rfe_id:1115][crit:high][test_id:1357]succeed creating import dv with given valid url", dataVolumeTestArguments{
 				name:             "dv-http-import",
 				size:             "1Gi",
@@ -715,7 +717,7 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 				runningCondition: &cdiv1.DataVolumeCondition{
 					Type:    cdiv1.DataVolumeRunning,
 					Status:  v1.ConditionFalse,
-					Message: "Import Complete",
+					Message: "Import Complete; VDDK: {\"Version\":\"1.2.3\",\"Host\":\"esx.test\"}",
 					Reason:  "Completed",
 				}}),
 			table.Entry("[test_id:5078]succeed creating warm import dv from VDDK source", dataVolumeTestArguments{
@@ -739,11 +741,52 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 				runningCondition: &cdiv1.DataVolumeCondition{
 					Type:    cdiv1.DataVolumeRunning,
 					Status:  v1.ConditionFalse,
-					Message: "Import Complete",
+					Message: "Import Complete; VDDK: {\"Version\":\"1.2.3\",\"Host\":\"esx.test\"}",
 					Reason:  "Completed",
 				}}),
 		)
 
+		// Similar to previous table, but with additional cleanup steps
+		table.DescribeTable("should", func(args dataVolumeTestArguments) {
+			configMap, err := RunKubectlCommand(f, "get", "configmap", "-o", "yaml", "-n", f.CdiInstallNs, common.VddkConfigMap)
+			Expect(err).ToNot(HaveOccurred())
+
+			_, err = RunKubectlCommand(f, "delete", "configmap", "-n", f.CdiInstallNs, common.VddkConfigMap)
+			Expect(err).ToNot(HaveOccurred())
+
+			defer func() {
+				command := CreateKubectlCommand(f, "create", "-n", f.CdiInstallNs, "-f", "-")
+				command.Stdin = strings.NewReader(configMap)
+				err := command.Run()
+				Expect(err).ToNot(HaveOccurred())
+			}()
+
+			testDataVolume(args)
+		},
+			table.Entry("[test_id:5079]should fail with \"AwaitingVDDK\" reason when VDDK credentials config map is not present", dataVolumeTestArguments{
+				name:             "dv-awaiting-vddk",
+				size:             "1Gi",
+				url:              vcenterURL,
+				dvFunc:           createVddkDataVolume,
+				eventReason:      common.AwaitingVDDK,
+				phase:            cdiv1.ImportScheduled,
+				checkPermissions: false,
+				readyCondition: &cdiv1.DataVolumeCondition{
+					Type:   cdiv1.DataVolumeReady,
+					Status: v1.ConditionFalse,
+				},
+				boundCondition: &cdiv1.DataVolumeCondition{
+					Type:    cdiv1.DataVolumeBound,
+					Status:  v1.ConditionFalse,
+					Message: fmt.Sprintf("waiting for %s configmap for VDDK image", common.VddkConfigMap),
+					Reason:  common.AwaitingVDDK,
+				},
+				runningCondition: &cdiv1.DataVolumeCondition{
+					Type:   cdiv1.DataVolumeRunning,
+					Status: v1.ConditionFalse,
+				}}),
+		)
+
 		It("[test_id:4961]should handle a pre populated PVC", func() {
 			By(fmt.Sprintf("initializing source PVC %s", dataVolumeName))
 			sourcePodFillerName := fmt.Sprintf("%s-filler-pod", dataVolumeName)
@@ -986,7 +1029,7 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 		}
 
 		It("[test_id:5353]Importer pod should have specific datavolume annotations passed but not others", func() {
-			dataVolume := utils.NewDataVolumeWithHTTPImport(dataVolumeName, "1Gi", fmt.Sprintf(utils.TinyCoreQcow2URLRateLimit, f.CdiInstallNs))
+			dataVolume := utils.NewDataVolumeWithHTTPImport(dataVolumeName, "1Gi", fmt.Sprintf(utils.TinyCoreQcow2URL, f.CdiInstallNs))
 			By(fmt.Sprintf("creating new datavolume %s with annotations", dataVolume.Name))
 			dataVolume.Annotations[controller.AnnPodNetwork] = "net1"
 			dataVolume.Annotations["annot1"] = "value1"
@@ -998,18 +1041,14 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 			Expect(err).ToNot(HaveOccurred())
 			f.ForceBindIfWaitForFirstConsumer(pvc)
 
-			By("verifying the Datavolume is not complete yet")
-			foundDv, err := f.CdiClient.CdiV1beta1().DataVolumes(dataVolume.Namespace).Get(context.TODO(), dataVolume.Name, metav1.GetOptions{})
-			Expect(err).ToNot(HaveOccurred())
-			if foundDv.Status.Phase != cdiv1.Succeeded {
-				By("find importer pod")
-				var sourcePod *v1.Pod
-				Eventually(func() bool {
-					sourcePod, err = utils.FindPodByPrefix(f.K8sClient, dataVolume.Namespace, common.ImporterPodName, common.CDILabelSelector)
-					return err == nil
-				}, timeout, pollingInterval).Should(BeTrue())
-				verifyAnnotations(sourcePod)
-			}
+			By("find importer pod")
+			var sourcePod *v1.Pod
+			Eventually(func() bool {
+				sourcePod, err = utils.FindPodByPrefix(f.K8sClient, dataVolume.Namespace, common.ImporterPodName, common.CDILabelSelector)
+				return err == nil
+			}, timeout, pollingInterval).Should(BeTrue())
+			By(fmt.Sprintf("Verifying pod %s has correct annotation", sourcePod.Name))
+			verifyAnnotations(sourcePod)
 		})
 
 		It("[test_id:5365]Uploader pod should have specific datavolume annotations passed but not others", func() {
@@ -1025,18 +1064,13 @@ var _ = Describe("[vendor:cnv-qe@redhat.com][level:component]DataVolume tests",
 			Expect(err).ToNot(HaveOccurred())
 			f.ForceBindIfWaitForFirstConsumer(pvc)
 
-			By("verifying the Datavolume is not complete yet")
-			foundDv, err := f.CdiClient.CdiV1beta1().DataVolumes(dataVolume.Namespace).Get(context.TODO(), dataVolume.Name, metav1.GetOptions{})
-			Expect(err).ToNot(HaveOccurred())
-			if foundDv.Status.Phase != cdiv1.Succeeded {
-				By("find uploader pod")
-				var sourcePod *v1.Pod
-				Eventually(func() bool {
-					sourcePod, err = utils.FindPodByPrefix(f.K8sClient, dataVolume.Namespace, "cdi-upload", common.CDILabelSelector)
-					return err == nil
-				}, timeout, pollingInterval).Should(BeTrue())
-				verifyAnnotations(sourcePod)
-			}
+			By("find uploader pod")
+			var sourcePod *v1.Pod
+			Eventually(func() bool {
+				sourcePod, err = utils.FindPodByPrefix(f.K8sClient, dataVolume.Namespace, "cdi-upload", common.CDILabelSelector)
+				return err == nil
+			}, timeout, pollingInterval).Should(BeTrue())
+			verifyAnnotations(sourcePod)
 		})
 
 		It("[test_id:5366]Cloner pod should have specific datavolume annotations passed but not others", func() {
